const { get, remove, concat } = require('lodash')
const config = require('config')

const {
  Team,
  services,
  authsome: authsomeHelper,
} = require('pubsweet-component-helper-service')

const {
  deleteFilesS3,
} = require('pubsweet-component-mts-package/src/PackageManager')

const s3Config = get(config, 'pubsweet-component-aws-s3', {})

module.exports = models => async (req, res) => {
  const { collectionId } = req.params
  let collection, fragment
  try {
    collection = await models.Collection.find(collectionId)

    const fragmentId = collection.fragments[0]
    if (!collection.fragments.includes(fragmentId))
      return res.status(400).json({
        error: `Collection and fragment do not match.`,
      })

    fragment = await models.Fragment.find(fragmentId)

    const authsome = authsomeHelper.getAuthsome(models)

    const canDelete = await authsome.can(req.user, 'DELETE', collection)
    if (!canDelete)
      return res.status(403).json({
        error: 'Unauthorized.',
      })

    const teamHelper = new Team({
      TeamModel: models.Team,
      fragmentId,
      collectionId,
    })
    const team = await teamHelper.getTeam({
      role: 'author',
      objectType: 'fragment',
    })

    await Promise.all(
      team.members.map(async member => {
        const user = await models.User.find(member)

        remove(user.teams, teamId => teamId === team.id)

        return user.save()
      }),
    )

    await team.delete()

    const fileKeys = concat(
      fragment.files.manuscripts,
      fragment.files.coverLetter,
      fragment.files.supplementary,
    ).map(file => `${fragment.id}/${file.id}`)

    if (fileKeys.length !== 0) {
      await deleteFilesS3({ fileKeys, s3Config })
    }

    await fragment.delete()

    await collection.delete()

    return res.status(200).json()
  } catch (e) {
    const notFoundError = await services.handleNotFoundError(e, 'Item')
    return res.status(notFoundError.status).json({
      error: notFoundError.message,
    })
  }
}
